barvinok: Projections of integer point sets of parametric polytopes
===================================================================

Description
-----------

barvinok is a library for counting the number of integer points in
parametric and non-parametric polytopes as well as projections of such
sets.

License
-------

GPL v2


Upstream Contact
----------------

-  http://groups.google.com/group/isl-development
